PulseBase<T> class abstract

Constructors

PulseBase(T _state)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state → T
no setter
stream Stream<T>
no setter

Methods

close() → void
listen(PulseListener<T> listener) StreamSubscription<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onClose() → void
onPush(T state) → void
push(T state) → void
reset() → void
setState(T updater(T current)) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited